<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="63"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile 插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>PCM Files</source>
        <translation>PCM 檔案</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="130"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>關於 Sndfile 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="131"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Qmmp Sndfile 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="132"/>
        <source>Compiled against</source>
        <translation>編譯依賴於</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="133"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
